@@ -17,23 +17,19 @@
 """Provision test environment for specific DB backends"""
 
 import abc
-import debtcollector
 import logging
 import os
 import random
 import re
 import string
 
-import six
-from six import moves
 import sqlalchemy
-from sqlalchemy.engine import url as sa_url
 from sqlalchemy import schema
+from sqlalchemy import sql
 import testresources
 
 from oslo_db import exception
 from oslo_db.sqlalchemy import enginefacade
-from oslo_db.sqlalchemy import session
 from oslo_db.sqlalchemy import utils
 
 LOG = logging.getLogger(__name__)
@@ -160,27 +156,6 @@ class DatabaseResource(testresources.TestResourceManager):
         return False
 
 
-@debtcollector.removals.removed_class("TransactionResource")
-class TransactionResource(testresources.TestResourceManager):
-
-    def __init__(self, database_resource, schema_resource):
-        super(TransactionResource, self).__init__()
-        self.resources = [
-            ('database', database_resource),
-            ('schema', schema_resource)
-        ]
-
-    def clean(self, resource):
-        resource._dispose()
-
-    def make(self, dependency_resources):
-        conn = dependency_resources['database'].engine.connect()
-        return utils.NonCommittingEngine(conn)
-
-    def isDirty(self):
-        return True
-
-
 class SchemaResource(testresources.TestResourceManager):
 
     def __init__(self, database_resource, generate_schema, teardown=False):
@@ -266,7 +241,6 @@ class Backend(object):
         :raises: ``BackendNotAvailable`` if the backend is not available.
 
         """
-
         if not self.verified:
             try:
                 eng = self._ensure_backend_available(self.url)
@@ -283,12 +257,12 @@ class Backend(object):
 
     @classmethod
     def _ensure_backend_available(cls, url):
-        url = sa_url.make_url(str(url))
+        url = utils.make_url(url)
         try:
             eng = sqlalchemy.create_engine(url)
         except ImportError as i_e:
             # SQLAlchemy performs an "import" of the DBAPI module
-            # within create_engine().  So if ibm_db_sa, cx_oracle etc.
+            # within create_engine().  So if mysql etc.
             # isn't installed, we get an ImportError here.
             LOG.info(
                 "The %(dbapi)s backend is unavailable: %(err)s",
@@ -361,17 +335,6 @@ class Backend(object):
         """
         return self.impl.provisioned_database_url(self.url, ident)
 
-    @debtcollector.removals.remove()
-    def provisioned_engine(self, ident):
-        """Given the URL of a particular database backend and the string
-
-        name of a particular 'database' within that backend, return
-        an Engine instance whose connections will refer directly to the
-        named database.
-
-        """
-        return self.impl.provisioned_engine(self.url, ident)
-
     @classmethod
     def _setup(cls):
         """Initial startup feature will scan the environment for configured
@@ -397,15 +360,14 @@ class Backend(object):
             ]
 
         for url_str in configured_urls:
-            url = sa_url.make_url(url_str)
+            url = utils.make_url(url_str)
             m = re.match(r'([^+]+?)(?:\+(.+))?$', url.drivername)
             database_type = m.group(1)
             Backend.backends_by_database_type[database_type] = \
                 Backend(database_type, url)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BackendImpl(object):
+class BackendImpl(object, metaclass=abc.ABCMeta):
     """Provide database-specific implementations of key provisioning
 
     functions.
@@ -530,59 +492,31 @@ class BackendImpl(object):
         then emit a command to switch to the named database.
 
         """
+        url = utils.make_url(base_url)
+        url = url.set(database=ident)
 
-        url = sa_url.make_url(str(base_url))
-        url.database = ident
         return url
 
-    @debtcollector.removals.remove()
-    def provisioned_engine(self, base_url, ident):
-        """Return a provisioned engine.
-
-        Given the URL of a particular database backend and the string
-        name of a particular 'database' within that backend, return
-        an Engine instance whose connections will refer directly to the
-        named database.
-
-        For hostname-based URLs, this typically involves switching just the
-        'database' portion of the URL with the given name and creating
-        an engine.
-
-        For URLs that instead deal with DSNs, the rules may be more custom;
-        for example, the engine may need to connect to the root URL and
-        then emit a command to switch to the named database.
-
-        """
-        url = self.provisioned_database_url(base_url, ident)
-
-        return session.create_engine(
-            url,
-            logging_name="%s@%s" % (self.drivername, ident),
-            **self.default_engine_kwargs
-        )
-
 
 @BackendImpl.impl.dispatch_for("mysql")
 class MySQLBackendImpl(BackendImpl):
 
-    # only used for deprecated provisioned_engine() function.
-    default_engine_kwargs = {'mysql_sql_mode': 'TRADITIONAL'}
-
     def create_opportunistic_driver_url(self):
         return "mysql+pymysql://openstack_citest:openstack_citest@localhost/"
 
     def create_named_database(self, engine, ident, conditional=False):
-        with engine.connect() as conn:
+        with engine.begin() as conn:
             if not conditional or not self.database_exists(conn, ident):
-                conn.execute("CREATE DATABASE %s" % ident)
+                conn.exec_driver_sql("CREATE DATABASE %s" % ident)
 
     def drop_named_database(self, engine, ident, conditional=False):
-        with engine.connect() as conn:
+        with engine.begin() as conn:
             if not conditional or self.database_exists(conn, ident):
-                conn.execute("DROP DATABASE %s" % ident)
+                conn.exec_driver_sql("DROP DATABASE %s" % ident)
 
     def database_exists(self, engine, ident):
-        return bool(engine.scalar("SHOW DATABASES LIKE '%s'" % ident))
+        s = sql.text("SHOW DATABASES LIKE :ident")
+        return bool(engine.scalar(s, {'ident': ident}))
 
 
 @BackendImpl.impl.dispatch_for("sqlite")
@@ -624,7 +558,7 @@ class SQLiteBackendImpl(BackendImpl):
 
     def provisioned_database_url(self, base_url, ident):
         if base_url.database:
-            return sa_url.make_url("sqlite:////tmp/%s.db" % ident)
+            return utils.make_url("sqlite:////tmp/%s.db" % ident)
         else:
             return base_url
 
@@ -632,37 +566,40 @@ class SQLiteBackendImpl(BackendImpl):
 @BackendImpl.impl.dispatch_for("postgresql")
 class PostgresqlBackendImpl(BackendImpl):
     def create_opportunistic_driver_url(self):
-        return "postgresql://openstack_citest:openstack_citest"\
-            "@localhost/postgres"
+        return "postgresql+psycopg2://openstack_citest:openstack_citest@localhost/postgres"  # noqa: E501
 
     def create_named_database(self, engine, ident, conditional=False):
         with engine.connect().execution_options(
-                isolation_level="AUTOCOMMIT") as conn:
+            isolation_level="AUTOCOMMIT",
+        ) as conn:
             if not conditional or not self.database_exists(conn, ident):
-                conn.execute("CREATE DATABASE %s" % ident)
+                conn.exec_driver_sql("CREATE DATABASE %s" % ident)
 
     def drop_named_database(self, engine, ident, conditional=False):
         with engine.connect().execution_options(
-                isolation_level="AUTOCOMMIT") as conn:
+            isolation_level="AUTOCOMMIT",
+        ) as conn:
             self._close_out_database_users(conn, ident)
             if conditional:
-                conn.execute("DROP DATABASE IF EXISTS %s" % ident)
+                conn.exec_driver_sql("DROP DATABASE IF EXISTS %s" % ident)
             else:
-                conn.execute("DROP DATABASE %s" % ident)
+                conn.exec_driver_sql("DROP DATABASE %s" % ident)
 
     def drop_additional_objects(self, conn):
         enums = [e['name'] for e in sqlalchemy.inspect(conn).get_enums()]
 
         for e in enums:
-            conn.execute("DROP TYPE %s" % e)
+            conn.exec_driver_sql("DROP TYPE %s" % e)
 
     def database_exists(self, engine, ident):
         return bool(
             engine.scalar(
                 sqlalchemy.text(
-                    "select datname from pg_database "
-                    "where datname=:name"), name=ident)
+                    "SELECT datname FROM pg_database WHERE datname=:name"
+                ),
+                {'name': ident},
             )
+        )
 
     def _close_out_database_users(self, conn, ident):
         """Attempt to guarantee a database can be dropped.
@@ -681,18 +618,18 @@ class PostgresqlBackendImpl(BackendImpl):
         if conn.dialect.server_version_info >= (9, 2):
             conn.execute(
                 sqlalchemy.text(
-                    "select pg_terminate_backend(pid) "
-                    "from pg_stat_activity "
-                    "where usename=current_user and "
-                    "pid != pg_backend_pid() "
-                    "and datname=:dname"
-                ), dname=ident)
+                    "SELECT pg_terminate_backend(pid) "
+                    "FROM pg_stat_activity "
+                    "WHERE usename=current_user AND "
+                    "pid != pg_backend_pid() AND "
+                    "datname=:dname"
+                ),
+                {'dname': ident},
+            )
 
 
 def _random_ident():
-    return ''.join(
-        random.choice(string.ascii_lowercase)
-        for i in moves.range(10))
+    return ''.join(random.choice(string.ascii_lowercase) for i in range(10))
 
 
 Backend._setup()
